r"""
                     _            _____
     /\             | |     /\   |_   _|
    /  \    ______ _| |_   /  \    | |
   / /\ \  |_  / _` | __| / /\ \   | |
  / ____ \  / / (_| | |_ / ____ \ _| |_
 /_/    \_\/___\__,_|\__/_/    \_\_____|
"""

__title__ = "UniSense Xlink"
__version__ = "0.1.1"
__author__ = "Yaakov Azat"
__license__ = "AzatAI License"
__copyright__ = "Copyright 2020-2021 Azat Artificial Intelligence, LLP"

# Version synonym
VERSION = __version__

# Header encoding (see RFC5987)
HTTP_HEADER_ENCODING = "iso-8859-1"

# Default datetime input and output formats
ISO_8601 = "iso-8601"